@@ -20,9 +20,7 @@ test_that("parisk function calculates parisk correctly", {
                 se = se,
                 scaleval = scale,
                 ordered_dimension = ordered,
-                favourable_indicator = fav,
-                reference_subgroup = ref
-                )
+                favourable_indicator = fav)
 
   # Expected values
   expected_parisk <- 16.293152
